function [ab,dig]=dig_explog(dig0,dd,nofdig)
%DIG_EXPLOG Number of digits needed for a weight function on 
%[0,Inf] with an algebraic/extended-logarithmic singularity.
%   [AB,DIG]=DIG_EXPLOG(N,DIG0,DD,NOFDIG) determines the number
%   DIG of digits needed to obtain the first N recurrence coefficients
%   for the weight function w(x)=x^A*exp(-x)*log(1+1/x) on [0,Inf] 
%   to an accuracy of NOFDIG decimal digits using a 2-component
%   discretization procedure. The routine successively increments an
%   initial estimate DIG0 by DD units until the required accuracy is 
%   achieved. The recurrence coefficients to NOFDIG digits are placed 
%   into the Nx2 array AB. The parameter A, either equal to 0, 1, 3, 
%   or 5, must be entered when prompted. The corresponding values 
%   of N are 65, 64, 63, and 62, and are so selected in the routine
%   sOPexplog.m.

global a dig 
a=input('enter the value of a, either equal to 0, 1, 3 or 5');
maxerr=1; eps0=.5*10^(-nofdig);
i=dig0-dd; 
while maxerr>eps0
  i=i+dd; dig=i
  if i==dig0
    ab0=sOPexplog(dig,a);
  else
    ab1=sOPexplog(dig,a);
    serr=abs((ab1-ab0)./ab1);
    err=double(serr);
    maxerr=max(max(err)); 
    ab0=ab1;
  end
end
ab=vpa(ab1,nofdig);
